@@ -19,7 +19,7 @@
  * USA
  */
 
-#include "config.h"
+#include <config.h>
 
 #include <string.h>
 #include <locale.h>
@@ -42,24 +42,29 @@
 #include <libgnomeui/gnome-ui-init.h>
 #endif /* HAVE_GNOME */
 
-#ifdef HAVE_MAEMO
+#ifdef HAVE_HILDON
 #include <libosso.h>
+
+#ifdef HAVE_MAEMO_3
 #include <osso-browser-interface.h>
 #include <hildon-widgets/hildon-program.h>
+#else
+#include <hildon/hildon-program.h>
+#endif /* HAVE_MAEMO_3 */
 
 #define SERVICE_NAME "org.gnome.Games.AisleRiot"
 #define HELP_EXT "xhtml"
-
-#endif /* HAVE_MAEMO */
+#endif /* HAVE_HILDON */
 
 #if defined (G_OS_WIN32)
 #include <windows.h>
 #include <io.h>
 #define HELP_EXT "xhtml"
-//FIXME On win32 help is created as html with gnome-doc-tool,
-//and put manually in the directory below.
+/* FIXME On win32 help is created as html with gnome-doc-tool,
+ * and put manually in the directory below.
+ */
 #define HELPDIR PKGDATADIR "/aisleriot/help"
-#endif
+#endif /* G_OS_WIN32 */
 
 #include <libgames-support/games-files.h>
 #include <libgames-support/games-stock.h>
@@ -78,7 +83,7 @@ typedef struct {
 #ifdef HAVE_GNOME
   GnomeProgram *program;
 #endif
-#ifdef HAVE_MAEMO
+#ifdef HAVE_HILDON
   osso_context_t *osso_context;
   HildonProgram *program;
 #endif
@@ -247,7 +252,7 @@ game_file_to_help_section (const char *game_file)
   return buf;
 }
 
-#if (defined HAVE_MAEMO || defined G_OS_WIN32)
+#if defined (HAVE_HILDON) || defined (G_OS_WIN32)
 
 static void
 help_hook (GtkWindow *parent,
@@ -394,12 +399,12 @@ help_hook (GtkWindow *parent,
     g_free (primary);
     g_error_free (error);
 
-#ifdef HAVE_MAEMO
+#ifdef HAVE_HILDON
   /* Empty title shows up as "<unnamed>" on maemo */
   gtk_window_set_title (GTK_WINDOW (dialog), _("Error"));
 #else
   gtk_window_set_title (GTK_WINDOW (dialog), "");
-#endif /* HAVE_MAEMO */
+#endif /* HAVE_HILDON */
 
     gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
 
@@ -415,7 +420,7 @@ help_hook (GtkWindow *parent,
 #endif /* !HAVE_GNOME */
 }
 
-#endif /* HAVE_MAEMO */
+#endif /* HAVE_HILDON */
 
 #ifdef HAVE_MAEMO
 
@@ -511,7 +516,7 @@ main_prog (void *closure, int argc, char *argv[])
   GError *error = NULL;
   gboolean retval;
 #endif
-#if HAVE_MAEMO
+#ifdef HAVE_MAEMO
   osso_hw_state_t hw_events = {
     TRUE /* shutdown */,
     TRUE /* save unsaved data */,
@@ -635,15 +640,17 @@ main_prog (void *closure, int argc, char *argv[])
                             G_CALLBACK (die_cb), &data);
 #endif /* HAVE_GNOME */
 
-#ifdef HAVE_MAEMO
+#ifdef HAVE_HILDON
   hildon_program_add_window (data.program, HILDON_WINDOW (data.window));
 
   /* FIXMEchpe sort of strange that maemo doesn't all of this out-of-the-box... */
   g_object_set (gtk_widget_get_settings (GTK_WIDGET (data.window)),
                 "gtk-alternative-button-order", TRUE,
-                "gtk-menu-images", FALSE,
-                "gtk-button-images", FALSE,
                 "gtk-toolbar-style", (glong) GTK_TOOLBAR_ICONS,
+                "gtk-menu-images", FALSE,
+#ifdef HAVE_MAEMO_3
+                "gtk-button-images", FALSE,
+#endif /* HAVE_MAEMO_3 */
 #if GTK_CHECK_VERSION (2, 10, 0)
                 "gtk-enable-accels", FALSE,
                 "gtk-enable-mnemonics", FALSE,
@@ -693,8 +700,8 @@ main (int argc, char *argv[])
 
   setlocale (LC_ALL, "");
 
-#if defined(HAVE_GNOME) || defined(HAVE_RSVG_GNOMEVFS)
-  /* If we're going to use gnome-vfs, we need to init threads before
+#if defined(HAVE_GNOME) || defined(HAVE_RSVG_GNOMEVFS) || defined(HAVE_GSTREAMER)
+  /* If we're going to use gnome-vfs or gstreamer, we need to init threads before
    * calling any glib functions.
    */
   g_thread_init (NULL);
