@@ -15,7 +15,7 @@ if (sys.modules.has_key('glchess') and
     # If the installed_mode attribute is not set, then we are
     # importing from something other than the glchess script; we
     # assume anyone importing in this way is doing testing etc.
-    APP_DATA_DIR     = os.path.join('/home/thomas/newsvn/test', 'share') 
+    APP_DATA_DIR     = os.path.join('/usr/local', 'share') 
     ICON_DIR         = os.path.join(APP_DATA_DIR, 'pixmaps')
     TEXTURE_DIR      = os.path.join(ICON_DIR, 'glchess')
     GLADE_DIR        = os.path.join(APP_DATA_DIR, 'glchess')
@@ -28,11 +28,11 @@ if (sys.modules.has_key('glchess') and
     UNFINISHED_FILE  = os.path.join(HISTORY_DIR, 'unfinished')
     LOCAL_AI_CONFIG  = os.path.join(DATA_DIR, 'ai.xml')
 else:
-    APP_DATA_DIR     = os.path.join('/home/thomas/newsvn/gnome-games', 'glchess', 'data')
-    ICON_DIR         = os.path.join('/home/thomas/newsvn/gnome-games', 'glchess', 'textures')
-    TEXTURE_DIR      = os.path.join('/home/thomas/newsvn/gnome-games', 'glchess', 'textures')
-    GLADE_DIR        = os.path.join('/home/thomas/newsvn/gnome-games', 'glchess', 'glade')
-    BASE_DIR         = os.path.join('/home/thomas/newsvn/gnome-games', 'glchess', 'data')
+    APP_DATA_DIR     = os.path.join('/home/jclinton/gnome-games', 'glchess', 'data')
+    ICON_DIR         = os.path.join('/home/jclinton/gnome-games', 'glchess', 'textures')
+    TEXTURE_DIR      = os.path.join('/home/jclinton/gnome-games', 'glchess', 'textures')
+    GLADE_DIR        = os.path.join('/home/jclinton/gnome-games', 'glchess', 'glade')
+    BASE_DIR         = os.path.join('/home/jclinton/gnome-games', 'glchess', 'data')
     LOCALEDIR        = os.path.join(APP_DATA_DIR, 'locale')
     DATA_DIR         = os.path.expanduser('~/.gnome2/glchess/')
     LOG_DIR          = os.path.join(DATA_DIR, 'logs')
@@ -50,7 +50,7 @@ import gtk.glade
 gtk.glade.bindtextdomain(DOMAIN, LOCALEDIR)
 gtk.glade.textdomain(DOMAIN)
 
-VERSION   = "2.21.92"
+VERSION   = "2.22.0"
 APPNAME   = _("glChess")
 ICON_NAME = 'gnome-glchess'
 
