@@ -111,7 +111,7 @@ class GtkViewArea(gtk.DrawingArea):
         glContext = gtk.gtkgl.widget_get_gl_context(self)
 
         # OpenGL begin.
-        if not glDrawable.gl_begin(glContext):
+        if glDrawable is None or not glDrawable.gl_begin(glContext):
             return
         
         self.__glDrawable = glDrawable
@@ -130,10 +130,8 @@ class GtkViewArea(gtk.DrawingArea):
         
     def __endGL(self):
         """Free the OpenGL context"""
-        if not self.renderGL:
+        if self.__glDrawable is None or not self.renderGL:
             return
-        
-        assert(self.__glDrawable is not None)
         self.__glDrawable.gl_end()
         self.__glDrawable = None
         
@@ -155,7 +153,9 @@ class GtkViewArea(gtk.DrawingArea):
         """Gtk+ signal"""
         if self.renderGL:
             self.__startGL()
-        
+            if self.__glDrawable is None:
+                return
+
             # Get the scene rendered
             try:
                 if self.view.feedback is not None:
@@ -405,9 +405,15 @@ class GtkView(glchess.ui.ViewController):
         if status is not None:
             subs['result'] = status
         haveResult = status is not None
-            
-        subs['move'] = {True:  _('%(movenum)2iw.') % subs,
-                        False: _('%(movenum)2ib.') % subs}[isWhite]
+        
+        # Translators: This string is used in the move history to indicate which white move is being described.
+        # In a chess game the turns are '1w.', '1b.', '2w.', ...
+        whiteMovePrefix = _('%(movenum)2iw.') % subs
+        # Translators: This string is used in the move history to indicate which black move is being described.
+        # In a chess game the turns are '1w.', '1b.', '2w.', ...
+        blackMovePrefix = _('%(movenum)2ib.') % subs
+        subs['move'] = {True:  whiteMovePrefix,
+                        False: blackMovePrefix}[isWhite]
 
         if move.sanMove.startswith('O-O-O'):
             string = {(True, True):   _('%(move)s White castles long (%(result)s)'),
