@@ -48,7 +48,7 @@ class GtkNetworkGameDialog(glchess.ui.NetworkController):
         view = self.__gui.get_widget('room_list')
         view.set_model(self.roomModel)
         cell = gtk.CellRendererText()
-        column = gtk.TreeViewColumn(_('#'), cell)
+        column = gtk.TreeViewColumn('', cell)
         column.add_attribute(cell, 'text', 3)
         view.append_column(column)
         cell = gtk.CellRendererPixbuf()
@@ -56,13 +56,13 @@ class GtkNetworkGameDialog(glchess.ui.NetworkController):
         column.add_attribute(cell, 'icon-name', 7)
         view.append_column(column)
         cell = gtk.CellRendererText()
-        column = gtk.TreeViewColumn(_('Room'), cell)
+        column = gtk.TreeViewColumn('', cell)
         column.add_attribute(cell, 'text', 2)
         column.add_attribute(cell, 'weight', 5)
         column.add_attribute(cell, 'style', 6)
         view.append_column(column)
         cell = gtk.CellRendererText()
-        column = gtk.TreeViewColumn(_('Description'), cell)
+        column = gtk.TreeViewColumn('', cell)
         column.add_attribute(cell, 'text', 4)
         #view.append_column(column)
         view.connect('row-activated', self._on_room_changed)
@@ -76,7 +76,7 @@ class GtkNetworkGameDialog(glchess.ui.NetworkController):
         column.add_attribute(cell, 'icon-name', 2)
         view.append_column(column)
         cell = gtk.CellRendererText()
-        column = gtk.TreeViewColumn(_('Player'), cell)
+        column = gtk.TreeViewColumn('', cell)
         column.add_attribute(cell, 'text', 1)
         view.append_column(column)
 
